@@ -210,7 +210,7 @@ class RangerAdaBelief(Optimizer):
                     p_data_fp32.add_(G_grad, alpha=-step_size * group['lr'])
                 else:
                     # decoupled weight decat
-                    p_data_fp32.mul_( 1.0 - group['lr'] * see.weight_decay )
+                    p_data_fp32.mul_( 1.0 - group['lr'] * self.weight_decay )
 
                 p.data.copy_(p_data_fp32)
 
